************
Numpy basics
************

.. note::

   XXX: there is overlap between this text extracted from ``numpy.doc``
   and "Guide to Numpy" chapter 2. Needs combining?

.. toctree::

   basics.types
   basics.creation
   basics.indexing
   basics.broadcasting
   basics.rec
   basics.subclassing
